@@ -7,6 +7,7 @@ from clu.abstract import Slotted, AppName, Cloneable, ReprWrapper
 from clu.constants.consts import PROJECT_NAME, NoDefault
 from clu.config.abc import NAMESPACE_SEP, NamespacedMutableMapping
 from clu.predicates import tuplize
+from clu.typology import iterlen
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -81,8 +82,8 @@ class EnvBase(NamespacedMutableMapping, AppName,
         """
         string = key.lstrip(cls.appname.upper() + PREFIX_SEP)
         if PREFIX_SEP not in string:
-            return string.lower()
-        return NAMESPACE_SEP.join(string.lower().split(PREFIX_SEP, 1))
+            return string.casefold()
+        return NAMESPACE_SEP.join(string.casefold().split(PREFIX_SEP, 1))
     
     def __init__(self, *args, **kwargs):
         """ Initialize the environment-variable mapping interface.
@@ -150,14 +151,14 @@ class EnvBase(NamespacedMutableMapping, AppName,
         """
         prefix = type(self).prefix(namespace=None)
         envkeys = (key.lstrip(prefix) for key in self.environment.keys() if key.startswith(prefix))
-        prefixes = frozenset(key.lower().split(PREFIX_SEP, 1)[0] for key in envkeys if PREFIX_SEP in key)
+        prefixes = frozenset(key.casefold().split(PREFIX_SEP, 1)[0] for key in envkeys if PREFIX_SEP in key)
         return tuple(sorted(prefixes))
     
     def inner_repr(self):
         """ Return some readable meta-information about this instance """
         prefix = type(self).prefix(namespace=None)
         namespaces = len(self.namespaces())
-        keys = len(list(self.keys()))
+        keys = iterlen(self.keys())
         return f"[prefix=“{prefix}*”, namespaces={namespaces}, keys={keys}]"
     
     def clone(self, *args, **kwargs):
