@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 from collections import defaultdict as DefaultDict
-from dataclasses import dataclass, field, fields
+from dataclasses import dataclass as dataclass_fn, field, fields
 from functools import lru_cache
 from itertools import chain
 
 cache = lambda function: lru_cache()(function)
 iterchain = chain.from_iterable
-reprless = dataclass(repr=False)
+dataclass = dataclass_fn(repr=False)
 
 import abc
 import clu.abstract
@@ -152,20 +152,17 @@ class ModuleSpec(importlib.machinery.ModuleSpec):
     
     """ A local “importlib.machinery.ModuleSpec” subclass
         that conveniently deals with setting the “origin”
-        attribute, and identifies all of its instances as
-        package modules.
+        attribute.
     """
     
     def __init__(self, name, loader):
         """ Initialize a new ModuleSpec, with a qualified (dotted)
             path string, and a module loader instance (both of which
-            are required).
+            are required arguments).
         """
         _, packagename = dotpath_split(name)
-        super(ModuleSpec, self).__init__(name,
-                                         loader,
-                                         origin=packagename,
-                                         is_package=True)
+        super(ModuleSpec, self).__init__(name, loader,
+                                         origin=packagename)
     
     def __hash__(self):
         return hash(self.loader) \
@@ -225,8 +222,13 @@ class FinderBase(clu.abstract.AppName,
         “initialize_types(…)” sub. to easily set these up for
         your own app.
         
-        The method “FinderBase.find_spec(…)” caches returned
-        instances of “ModuleSpec” using a ‘zict.LRU’ buffer.
+        The class method “FinderBase.find_spec(…)” caches its
+        returned instances of “ModuleSpec” using a ‘zict.LRU’
+        buffer, which is shared across all of the installed
+        “FinderBase” subclasses – meaning that if a spec has
+        been cached for one installed app via this mechanism,
+        it will be found by the first Finder subclass that
+        shows up in “sys.meta_path” to field a query for it (!)
     """
     
     specs = {}
@@ -234,12 +236,10 @@ class FinderBase(clu.abstract.AppName,
     
     @classmethod
     def find_spec(cls, fullname, path=None, target=None):
-        # N.B. this shouldn’t technically be a class method,
-        # but making it so fixed a bizarre bug where importing
-        # from the class-based module using the machinery of
-        # “from appname.appspace.xxx import xxx” would fail
-        # when the method was called unbound-method-style
-        # with classes like 'str' …?!
+        """ Return a ModuleSpec for a qualified module name –
+            creating an instance anew if necessary, and returning
+            an existing one from the cache if available.
+        """
         if fullname in cls.cache:
             return cls.cache[fullname]
         if cls.appname == fullname.split(consts.QUALIFIER).pop(0):
@@ -249,6 +249,11 @@ class FinderBase(clu.abstract.AppName,
     
     @classmethod
     def invalidate_caches(cls):
+        """ Clear both the Finder’s internal ModuleSpec instance
+            cache, and its associated Loader instances’ memoization
+            cache for the “create_module(…)” method (q.v. method
+            implementation sub.)
+        """
         cls.loader.create_module.cache_clear()
         cls.cache.clear()
         return None
@@ -262,10 +267,9 @@ class FinderBase(clu.abstract.AppName,
             § q.v. boxed notation sub., Python documentation,
               https://docs.python.org/3/library/pkgutil.html#pkgutil.iter_modules
         """
-        yield from (pkgutil.ModuleInfo(cls,
-                                       module.qualname,
-                                       ispkg=True) \
-                    for module in modules_for_appname(cls.appname))
+        yield from (pkgutil.ModuleInfo(cls, module.qualname, ispkg=False) \
+                                        for module \
+                                         in modules_for_appname(cls.appname))
 
 @export
 class LoaderBase(clu.abstract.AppName,
@@ -354,12 +358,14 @@ class ArgumentSink(object):
     """
     __slots__ = ('args', 'kwargs')
     
-    def __init__(self, *args, **kwargs):
-        """ Initialize an ArgumentSink, with arbitrary positional
+    def __new__(cls, *args, **kwargs):
+        """ Create a new ArgumentSink, with arbitrary positional
             and/or keyword arguments
         """
-        self.args = args
-        self.kwargs = kwargs
+        instance = object.__new__(cls)
+        instance.args = args
+        instance.kwargs = kwargs
+        return instance
     
     def __call__(self, function):
         """ Apply the sinks’ arguments to a function – or, indeed,
@@ -555,7 +561,7 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
                       super(ModuleBase, self).__dir__())
         return sorted(frozenset(names) - DO_NOT_INCLUDE)
 
-@reprless
+@dataclass
 class PerApp:
     
     """ Dataclass representing an “app”, as per the notion of
@@ -1030,16 +1036,11 @@ def test():
         else:
             pass
         
-        # pout.v(m.__dict__)
-        # print("m.__dict__:")
-        # pprint(m.__dict__)
-        
         assert m.appname == consts.PROJECT_NAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
         assert nameof(m) == consts.PROJECT_NAME
         
-        # pout.v(mro(m))
         print("mro(m):")
         pprint(mro(m))
         print()
@@ -1058,11 +1059,9 @@ def test():
         assert spec0.name == 'clu.app.FindMe'
         
         module0 = finder.loader.create_module(spec0)
-        # assert type(module0) is FindMe
         assert isinstance(module0, Module)
         
         module1 = finder.loader.create_module(spec0)
-        # assert type(module1) is FindMe
         assert isinstance(module1, Module)
         
         spec1 = finder.find_spec('clu.app.FindMe', [])
@@ -1090,7 +1089,6 @@ def test():
         
         from clu.app import Derived as derived
         
-        # assert type(derived) is Derived
         assert isinstance(derived, Module)
         assert derived.yo == 'dogg'
         
@@ -1106,6 +1104,9 @@ def test():
         print()
         
         assert type(derived.exporter).__name__ == 'Exporter'
+        
+        # Registry.unregister(derived.appname,
+        #                     derived.qualname)
     
     @inline
     def test_five():
@@ -1187,18 +1188,12 @@ def test():
                                                  # «Module1» …ooof.
         
         assert type(aux_module) is Module1
-        
-        # print()
-        # print("AUX MODULE TYPE:", type(aux_module))
-        # print("AUX MODULE REPR:", repr(aux_module))
-        # print()
     
     @inline
     def test_six_point_five():
         """ “PerApp” dataclass and module cache check """
         
         appnames = all_registered_appnames()
-        # appcount = len(appnames)
         
         for appname in appnames:
             
@@ -1229,14 +1224,19 @@ def test():
         plural = (speccount == 1) and "spec" or "specs"
         
         print(f"SPEC CACHE ({speccount} {plural} total):")
-        # pprint(FinderBase.specs, indent=4)
         
         for specname in sorted(FinderBase.specs.keys()):
             spec = FinderBase.specs[specname]
             string = pformat(spec.__dict__, indent=4)
+            cached = getattr(spec, 'cached', None)
+            hasloc = getattr(spec, 'has_location', None)
+            parent = getattr(spec, 'parent', None)
             print()
             print(f"    «{specname}»")
             print(f"{string}")
+            print(f"    +      cached: {cached}")
+            print(f"    +has_location: {hasloc}")
+            print(f"    +      parent: {parent}")
     
     @inline.diagnostic
     def show_monomers():
@@ -1273,7 +1273,7 @@ def test():
             print(f"{string}")
     
     # Run all tests:
-    inline.test(100)
+    return inline.test(100)
 
 if __name__ == '__main__':
-    test()
\ No newline at end of file
+    sys.exit(test())
\ No newline at end of file
